Class: Aws::ConnectCampaignService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCampaignService::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcampaignservice/client.rb,
sig/client.rbs
Overview
An API client for ConnectCampaignService. To construct a client, you need to configure a :region and :credentials.
client = Aws::ConnectCampaignService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateCampaignResponseSuccess, _DescribeCampaignResponseSuccess, _GetCampaignStateBatchResponseSuccess, _GetCampaignStateResponseSuccess, _GetConnectInstanceConfigResponseSuccess, _GetInstanceOnboardingJobStatusResponseSuccess, _ListCampaignsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutDialRequestBatchResponseSuccess, _StartInstanceOnboardingJobResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account.
-
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
-
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
-
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
-
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
-
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
-
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
-
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
-
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
-
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
-
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
-
#put_dial_request_batch(params = {}) ⇒ Types::PutDialRequestBatchResponse
Creates dials requests for the specified campaign Amazon Connect account.
-
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
-
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
-
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
-
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
-
#update_campaign_dialer_config(params = {}) ⇒ Struct
Updates the dialer config of a campaign.
-
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign.
-
#update_campaign_outbound_call_config(params = {}) ⇒ Struct
Updates the outbound call config of a campaign.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-connectcampaignservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1229 1230 1231 |
# File 'lib/aws-sdk-connectcampaignservice/client.rb', line 1229 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1232 1233 1234 |
# File 'lib/aws-sdk-connectcampaignservice/client.rb', line 1232 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 |
# File 'lib/aws-sdk-connectcampaignservice/client.rb', line 1202 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCampaignService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcampaignservice' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#create_campaign(params = {}) ⇒ Types::CreateCampaignResponse
Creates a campaign for the specified Amazon Connect account. This API is idempotent.
88 |
# File 'sig/client.rbs', line 88
def create_campaign: (
|
#delete_campaign(params = {}) ⇒ Struct
Deletes a campaign from the specified Amazon Connect account.
106 |
# File 'sig/client.rbs', line 106
def delete_campaign: (
|
#delete_connect_instance_config(params = {}) ⇒ Struct
Deletes a connect instance config from the specified AWS account.
112 |
# File 'sig/client.rbs', line 112
def delete_connect_instance_config: (
|
#delete_instance_onboarding_job(params = {}) ⇒ Struct
Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance.
118 |
# File 'sig/client.rbs', line 118
def delete_instance_onboarding_job: (
|
#describe_campaign(params = {}) ⇒ Types::DescribeCampaignResponse
Describes the specific campaign.
128 |
# File 'sig/client.rbs', line 128
def describe_campaign: (
|
#get_campaign_state(params = {}) ⇒ Types::GetCampaignStateResponse
Get state of a campaign for the specified Amazon Connect account.
138 |
# File 'sig/client.rbs', line 138
def get_campaign_state: (
|
#get_campaign_state_batch(params = {}) ⇒ Types::GetCampaignStateBatchResponse
Get state of campaigns for the specified Amazon Connect account.
149 |
# File 'sig/client.rbs', line 149
def get_campaign_state_batch: (
|
#get_connect_instance_config(params = {}) ⇒ Types::GetConnectInstanceConfigResponse
Get the specific Connect instance config.
159 |
# File 'sig/client.rbs', line 159
def get_connect_instance_config: (
|
#get_instance_onboarding_job_status(params = {}) ⇒ Types::GetInstanceOnboardingJobStatusResponse
Get the specific instance onboarding job status.
169 |
# File 'sig/client.rbs', line 169
def get_instance_onboarding_job_status: (
|
#list_campaigns(params = {}) ⇒ Types::ListCampaignsResponse
Provides summary information about the campaigns under the specified Amazon Connect account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
180 |
# File 'sig/client.rbs', line 180
def list_campaigns: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List tags for a resource.
197 |
# File 'sig/client.rbs', line 197
def list_tags_for_resource: (
|
#pause_campaign(params = {}) ⇒ Struct
Pauses a campaign for the specified Amazon Connect account.
203 |
# File 'sig/client.rbs', line 203
def pause_campaign: (
|
#put_dial_request_batch(params = {}) ⇒ Types::PutDialRequestBatchResponse
Creates dials requests for the specified campaign Amazon Connect account. This API is idempotent.
214 |
# File 'sig/client.rbs', line 214
def put_dial_request_batch: (
|
#resume_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
228 |
# File 'sig/client.rbs', line 228
def resume_campaign: (
|
#start_campaign(params = {}) ⇒ Struct
Starts a campaign for the specified Amazon Connect account.
234 |
# File 'sig/client.rbs', line 234
def start_campaign: (
|
#start_instance_onboarding_job(params = {}) ⇒ Types::StartInstanceOnboardingJobResponse
Onboard the specific Amazon Connect instance to Connect Campaigns.
244 |
# File 'sig/client.rbs', line 244
def start_instance_onboarding_job: (
|
#stop_campaign(params = {}) ⇒ Struct
Stops a campaign for the specified Amazon Connect account.
255 |
# File 'sig/client.rbs', line 255
def stop_campaign: (
|
#tag_resource(params = {}) ⇒ Struct
Tag a resource.
261 |
# File 'sig/client.rbs', line 261
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Untag a resource.
268 |
# File 'sig/client.rbs', line 268
def untag_resource: (
|
#update_campaign_dialer_config(params = {}) ⇒ Struct
Updates the dialer config of a campaign. This API is idempotent.
275 |
# File 'sig/client.rbs', line 275
def update_campaign_dialer_config: (
|
#update_campaign_name(params = {}) ⇒ Struct
Updates the name of a campaign. This API is idempotent.
282 |
# File 'sig/client.rbs', line 282
def update_campaign_name: (
|
#update_campaign_outbound_call_config(params = {}) ⇒ Struct
Updates the outbound call config of a campaign. This API is idempotent.
289 |
# File 'sig/client.rbs', line 289
def update_campaign_outbound_call_config: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1222 1223 1224 |
# File 'lib/aws-sdk-connectcampaignservice/client.rb', line 1222 def waiter_names [] end |